RDFCalendar.Store.DebugStore

Package RDFCalendar :: Module Store :: Class DebugStore |
[show private | hide private]
[frames | no frames]

## Class DebugStore

    AbstractStore --+
                    |
                   DebugStore

    A class displaying store operations.

Method Summary
| `__init__(self)`
| `add_attribute(self, parent, label)`
| `add_contains(self, node, element)`
| `add_name(self, node, name)`
| `add_node(self, attributes, label, uriref)`
| `add_value(self, attribute, label, value)`
| `has_item(self, uriref)`

Generated by Epydoc 2.1 on Sat Jul 7 19:42:53 2007 | http://epydoc.sf.net